c3kit.apron.bench

Cross-platform benchmarking macros: elapsed-time for one-shot timing, bench for repeated runs returning {:min :max :total :avg} in milliseconds.

Cross-platform benchmarking macros: `elapsed-time` for one-shot timing, `bench` for repeated runs returning `{:min :max :total :avg}` in milliseconds.
raw docstring

benchclj/smacro

(bench n & body)

Test how long a body will take to execute. This will only (do body). If you need to realize all results in a sequence, wrap your body in a doall. Body is executed n times.

Test how long a body will take to execute.
This will only `(do body)`. If you need to realize
all results in a sequence, wrap your body in a `doall`.
Body is executed n times.
raw docstring

elapsed-timeclj/smacro

(elapsed-time & body)

Evaluates the body and returns the elapsed time in milliseconds.

Evaluates the body and returns the elapsed time in milliseconds.
raw docstring

millis-nowclj/s

(millis-now)

millis-sinceclj/s

(millis-since millis-start)

performancecljs

cljdoc builds & hosts documentation for Clojure/Script libraries