c3kit.apron.refresh

Workflow-aware namespace reloading. Wraps clojure.tools.namespace so that registered services (see c3kit.apron.app) are stopped before reload and restarted after, keeping app state coherent during interactive development.

Workflow-aware namespace reloading. Wraps `clojure.tools.namespace` so that
registered services (see `c3kit.apron.app`) are stopped before reload and
restarted after, keeping app state coherent during interactive development.
raw docstring

clj-extensionsclj


excludesclj


initclj

(init s ns-prefix exclude-syms)

lockclj


ns-to-fileclj

(ns-to-file ns)
(ns-to-file ns extensions)

Returns a java.io.File corresponding to the clojure src file for the given namespace. nil is returned if the file is not found in the classpath or if the file is not a raw text file.

Returns a java.io.File corresponding to the clojure src file for the
given namespace.  nil is returned if the file is not found in the classpath
or if the file is not a raw text file.
raw docstring

ns-to-filenamesclj

(ns-to-filenames ns)
(ns-to-filenames ns extensions)

Converts the namespace name into a relative path for the corresponding clojure src file.

Converts the namespace name into a relative path for the corresponding clojure src file.
raw docstring

prefixclj


(print-error tracker)

refresh!clj

(refresh!)
(refresh! tracker)

refresh-handlerclj

(refresh-handler root-sym)

reloadclj

(reload tracker)

scanclj

(scan tracker)

servicesclj


trackerclj

cljdoc builds & hosts documentation for Clojure/Script libraries