c3kit.apron.schema.coercers

Pure coercion helpers and constructors used by both c3kit.apron.schema and c3kit.apron.schema.coercions. Owns no lexicon state — coercion lexes are bundled in c3kit.apron.schema.coercions and merged into the default lexicon by c3kit.apron.schema.

Named with the plural suffix to avoid the CLJS namespace/var clash with c3kit.apron.schema/coerce (the entity-level public fn).

Pure coercion helpers and constructors used by both c3kit.apron.schema
and c3kit.apron.schema.coercions. Owns no lexicon state — coercion
lexes are bundled in c3kit.apron.schema.coercions and merged into the
default lexicon by c3kit.apron.schema.

Named with the plural suffix to avoid the CLJS namespace/var clash
with c3kit.apron.schema/coerce (the entity-level public fn).
raw docstring

->bigdecclj/s

(->bigdec v)

->booleanclj/s

(->boolean value)

->dateclj/s

(->date v)

->floatclj/s

(->float v)

->intclj/s

(->int v)

->keywordclj/s

(->keyword value)

->mapclj/s

(->map m)

->seqclj/s

(->seq v)

->sql-dateclj/s

(->sql-date v)

->stringclj/s

(->string value)

->timestampclj/s

(->timestamp v)

->uriclj/s

(->uri v)

->uuidclj/s

(->uuid v)

->vecclj/s

(->vec v)

coerce-exclj/smacro

(coerce-ex value type)

dateclj/s


parse!cljs

(parse! f v)

str-or-nilclj/s

(str-or-nil v)

cljdoc builds & hosts documentation for Clojure/Script libraries