Ring middleware (wrap-verbose) that pretty-prints request and response maps to the log for development debugging.
Ring middleware (`wrap-verbose`) that pretty-prints request and response maps to the log for development debugging.
(make-body-printable body)(pretty-map value)(wrap-verbose handler)Prints request and response maps to STDOUT in a human-readable format.
Prints request and response maps to STDOUT in a human-readable format.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |