c3kit.apron.cursor

Defines a Cursor that wraps an atom (or atom-like structure) and provides a way to focus on a specific path within its nested data. It implements various Clojure interfaces to make it behave like an atom itself, with dereferencing, swapping, resetting, and watching capabilities.

Defines a Cursor that wraps an atom (or atom-like structure) and provides a way to focus on a
specific path within its nested data. It implements various Clojure interfaces to make it behave like an atom
itself, with dereferencing, swapping, resetting, and watching capabilities.
raw docstring

c3kit.apron.schema.doc

Shared infrastructure for doc-format renderers (OpenAPI, markdown, ...). Describes the expected shape of a route/doc spec and provides helpers that are format-agnostic.

Shared infrastructure for doc-format renderers (OpenAPI, markdown, ...).
Describes the expected shape of a route/doc spec and provides helpers that
are format-agnostic.
raw docstring

c3kit.apron.schema.path

Coordinate-based traversal of schemas and data. The grammar matches what schema/message-seq produces:

  • dot-separated keyword keys: a.b.c
  • [N] for seq indices: points[0]
  • ["..."] for string keys: crew["bill"]
  • [:kw] for explicit keywords: a[:joe]

For schemas, two reserved segment names provide access to dynamic templates:

  • :value — the :value-spec of a :map, or the :spec of a :seq
  • :key — the :key-spec of a :map

If the spec has no matching template (e.g. a :map with no :value-spec), :value and :key fall back to ordinary field lookup in :schema.

schema-at walks a schema tree (template semantics). data-at walks concrete data (supports an optional :lenient? option for keyword/string key equivalence).

Coordinate-based traversal of schemas and data. The grammar matches
what schema/message-seq produces:

- dot-separated keyword keys:    a.b.c
- [N] for seq indices:            points[0]
- ["..."] for string keys:       crew["bill"]
- [:kw] for explicit keywords:    a[:joe]

For schemas, two reserved segment names provide access to dynamic
templates:
- :value  — the :value-spec of a :map, or the :spec of a :seq
- :key    — the :key-spec of a :map

If the spec has no matching template (e.g. a :map with no :value-spec),
:value and :key fall back to ordinary field lookup in :schema.

schema-at walks a schema tree (template semantics).
data-at walks concrete data (supports an optional :lenient? option
for keyword/string key equivalence).
raw docstring

c3kit.apron.test-fabric

Truth is like the sun. You can shut it out for a time, but it ain't goin' away.

Truth is like the sun. You can shut it out for a time, but it ain't goin' away.
raw docstring

c3kit.apron.version

Runtime access to the apron version string.

Runtime access to the apron version string.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries