Pure coercion helpers and constructors used by both c3kit.apron.schema and c3kit.apron.schema.coercions. Owns no lexicon state — coercion lexes are bundled in c3kit.apron.schema.coercions and merged into the default lexicon by c3kit.apron.schema.
Named with the plural suffix to avoid the CLJS namespace/var clash with c3kit.apron.schema/coerce (the entity-level public fn).
Pure coercion helpers and constructors used by both c3kit.apron.schema and c3kit.apron.schema.coercions. Owns no lexicon state — coercion lexes are bundled in c3kit.apron.schema.coercions and merged into the default lexicon by c3kit.apron.schema. Named with the plural suffix to avoid the CLJS namespace/var clash with c3kit.apron.schema/coerce (the entity-level public fn).
(->bigdec v)(->boolean value)(->date v)(->float v)(->int v)(->keyword value)(->map m)(->seq v)(->sql-date v)(->string value)(->timestamp v)(->uri v)(->uuid v)(->vec v)(coerce-ex value type)(parse! f v)(str-or-nil v)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |